==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/AssigningShapeStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
export let AssigningShapeStyleEventArgsBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningShapeStyleEventArgsBaseDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningShapeStyleEventArgsBaseDescriptionMetadata.a == null) {
                AssigningShapeStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningShapeStyleEventArgsBaseDescriptionMetadata.c(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
            }
            if (a.k(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningShapeStyleEventArgsBaseDescriptionMetadata.b(a);
            a.ac("AssigningShapeStyleEventArgsBase", AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
    }
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningShapeStyleEventArgsBaseDescriptionMetadata, 'AssigningShapeStyleEventArgsBaseDescriptionMetadata');
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningShapeStyleEventArgsBaseDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/AssigningShapeStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
export let AssigningShapeStyleEventArgsBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningShapeStyleEventArgsBaseDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningShapeStyleEventArgsBaseDescriptionMetadata.a == null) {
                AssigningShapeStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningShapeStyleEventArgsBaseDescriptionMetadata.c(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
            }
            if (a.k(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningShapeStyleEventArgsBaseDescriptionMetadata.b(a);
            a.ad("AssigningShapeStyleEventArgsBase", AssigningShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
    }
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningShapeStyleEventArgsBaseDescriptionMetadata, 'AssigningShapeStyleEventArgsBaseDescriptionMetadata');
    AssigningShapeStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningShapeStyleEventArgsBaseDescriptionMetadata;
})();
